@@ -18,7 +18,7 @@ email                : sherman at mrcc.com
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/*  $Id: qgspggeoprocessing.cpp,v 1.20 2004/03/08 23:50:04 mcoletti Exp $ */
+/*  $Id: qgspggeoprocessing.cpp,v 1.25.2.1 2004/12/03 17:17:27 gsherman Exp $ */
 
 // includes
 #include <iostream>
@@ -26,7 +26,7 @@ email                : sherman at mrcc.com
 #include "../../src/qgisapp.h"
 #include "../../src/qgsmaplayer.h"
 #include "../../src/qgsvectorlayer.h"
-#include "../../src/qgsdataprovider.h"
+#include "../../src/qgsvectordataprovider.h"
 #include "../../src/qgsfield.h"
 
 #include <qtoolbar.h>
@@ -45,7 +45,7 @@ email                : sherman at mrcc.com
 
 static const char *pluginVersion = "0.1";
 
-static const char * const ident_ = "$Id: qgspggeoprocessing.cpp,v 1.20 2004/03/08 23:50:04 mcoletti Exp $";
+static const char * const ident_ = "$Id: qgspggeoprocessing.cpp,v 1.25.2.1 2004/12/03 17:17:27 gsherman Exp $";
 
 static const char * const name_ = "PostgresSQL Geoprocessing";
 static const char * const description_ = "Geoprocessing functions for working with PostgreSQL/PostGIS layers";
@@ -79,7 +79,9 @@ void QgsPgGeoprocessing::initGui()
   // add a menu with 2 items
   QPopupMenu *pluginMenu = new QPopupMenu(qgisMainWindow);
 
-  pluginMenu->insertItem(QIconSet(icon_buffer),"&Buffer Features", this, SLOT(buffer()));
+  int menuId = pluginMenu->insertItem(QIconSet(icon_buffer),"&Buffer Features", this, SLOT(buffer()));
+  pluginMenu->setWhatsThis(menuId, "Create a buffer for a PostgreSQL layer. "
+      "A new layer is created in the database with the buffered features.");
   //  pluginMenu->insertItem("&Unload Geoprocessing Plugin", this, SLOT(unload()));
 
   menu = ((QMainWindow *) qgisMainWindow)->menuBar();
@@ -87,16 +89,15 @@ void QgsPgGeoprocessing::initGui()
   //  menuId = menu->insertItem("&Geoprocessing", pluginMenu);
   menuId = qI->addMenu("&Geoprocessing", pluginMenu);
   // Create the action for tool
-  QAction *bufferAction = new QAction("Buffer features", QIconSet(icon_buffer), "&Buffer",
+  bufferAction = new QAction("Buffer features", QIconSet(icon_buffer), "&Buffer",
       0, this, "buffer");
+  bufferAction->setWhatsThis("Create a buffer for a PostgreSQL layer. "
+      "A new layer is created in the database with the buffered features.");
   // Connect the action to the zoomPrevous slot
   connect(bufferAction, SIGNAL(activated()), this, SLOT(buffer()));
-  // Add the toolbar
-  toolBar = new QToolBar((QMainWindow *) qgisMainWindow, "geoprocessing");
-  toolBar->setLabel("PostgreSQL/PostGIS Geoprocessing");
-  // Add the zoom previous tool to the toolbar
-  bufferAction->addTo(toolBar);
 
+  // Add the icon to the toolbar
+  qI->addToolBarIcon(bufferAction);
 
 }
 
@@ -142,6 +143,7 @@ void QgsPgGeoprocessing::buffer()
         user = user.mid(user.find("=") + 1);
 
         // show dialog to fetch buffer distrance, new layer name, and option to
+        // add the new layer to the map
         QgsDlgPgBuffer *bb = new QgsDlgPgBuffer(qI);
 
         // set the label
@@ -150,7 +152,7 @@ void QgsPgGeoprocessing::buffer()
         // set a default output table name
         bb->setBufferLayerName(tableName.mid(tableName.find(".") + 1) + "_buffer");
         // set the fields on the dialog box drop-down
-        QgsDataProvider *dp = lyr->getDataProvider();
+        QgsVectorDataProvider *dp = dynamic_cast<QgsVectorDataProvider *>(lyr->getDataProvider());
         std::vector < QgsField > flds = dp->fields();
         for (int i = 0; i < flds.size(); i++) {
           // check the field type -- if its int we can use it
@@ -324,10 +326,17 @@ void QgsPgGeoprocessing::buffer()
                 // host=localhost dbname=gis_data user=gsherman password= table=public.alaska (the_geom)
                 // Using addVectorLayer requires that be add a table=xxxx to the layer path since
                 // addVectorLayer is generic for all supported layers
-                qI->addVectorLayer(newLayerSource + "table=" + bb->schema() + "." + bb->bufferLayerName()
-                    + " (" + bb->geometryColumn() + ")",
-                    bb->schema() + "." + bb->bufferLayerName() + " (" + bb->geometryColumn() + ")", 
-                    "postgres");
+               std::cerr << "Building dataURI string" << std::endl; 
+                QString dataURI = newLayerSource + "table=" + bb->schema() + "." + bb->bufferLayerName()
+                    + " (" + bb->geometryColumn() + ")\n" +
+                    bb->schema() + "." + bb->bufferLayerName() + " (" + bb->geometryColumn() + ")\n" +
+                    "postgres"; 
+                    
+                    std::cerr << "Passing to addVectorLayer:\n" << dataURI << std::endl;
+                 qI->addVectorLayer(newLayerSource + "table=" + bb->schema() + "." + bb->bufferLayerName()
+                     + " (" + bb->geometryColumn() + ")",
+                 bb->schema() + "." + bb->bufferLayerName() + " (" + bb->geometryColumn() + ")", 
+                 "postgres"); 
 
               }
             } else {
@@ -406,7 +415,8 @@ void QgsPgGeoprocessing::unload()
 {
   // remove the GUI
   menu->removeItem(menuId);
-  delete toolBar;
+  qI->removeToolBarIcon(bufferAction);
+  delete bufferAction;
 }
 /** 
  * Required extern functions needed  for every plugin 
