@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: dbfopen.c,v 1.1 2004/04/05 15:39:45 timlinux Exp $
+ * $Id: dbfopen.c,v 1.2 2004/06/14 04:35:19 gsherman Exp $
  *
  * Project:  Shapelib
  * Purpose:  Implementation of .dbf access API documented in dbf_api.html.
@@ -34,6 +34,9 @@
  ******************************************************************************
  *
  * $Log: dbfopen.c,v $
+ * Revision 1.2  2004/06/14 04:35:19  gsherman
+ * Changes to support Windows version
+ *
  * Revision 1.1  2004/04/05 15:39:45  timlinux
  * Initial commit of new plugin to build graticules - not working yet! And thus not added to higher level makefiles yet.
  *
@@ -116,13 +119,15 @@
  */
 
 static char rcsid[] = 
-  "$Id: dbfopen.c,v 1.1 2004/04/05 15:39:45 timlinux Exp $";
+  "$Id: dbfopen.c,v 1.2 2004/06/14 04:35:19 gsherman Exp $";
 
 #include "shapefile.h"
 
 #include <math.h>
 #include <stdlib.h>
-
+#ifdef WIN32
+#include <string.h>
+#endif
 typedef unsigned char uchar;
 
 #ifndef FALSE
