@@ -1,9 +1,9 @@
 /***************************************************************************
   qgsdelimitedtextprovider.cpp -  Data provider for delimted text
   -------------------
-begin                : 2004-02-27
-copyright            : (C) 2004 by Gary E.Sherman
-email                : sherman at mrcc.com
+          begin                : 2004-02-27
+          copyright            : (C) 2004 by Gary E.Sherman
+          email                : sherman at mrcc.com
  ***************************************************************************/
 
 /***************************************************************************
@@ -14,13 +14,17 @@ email                : sherman at mrcc.com
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id: qgsdelimitedtextprovider.cpp,v 1.7 2004/05/16 20:39:45 mhugent Exp $ */
+/* $Id: qgsdelimitedtextprovider.cpp,v 1.18.2.1 2004/12/14 20:50:06 gsherman Exp $ */
 
 #include <iostream>
 #include <qfile.h>
 #include <qtextstream.h>
 #include <qstringlist.h>
+#include <qmessagebox.h>
+#include <qfiledialog.h>
+#include <qsettings.h>
 #include <qregexp.h>
+#include <ogrsf_frmts.h>
 #include "../../src/qgsdataprovider.h"
 #include "../../src/qgsfeature.h"
 #include "../../src/qgsfield.h"
@@ -28,6 +32,12 @@ email                : sherman at mrcc.com
 #include "qgsdelimitedtextprovider.h"
 #include <cfloat>
 
+#ifdef WIN32
+#define QGISEXTERN extern "C" __declspec( dllexport )
+#else
+#define QGISEXTERN extern "C"
+#endif
+
   QgsDelimitedTextProvider::QgsDelimitedTextProvider(QString uri)
 :mDataSourceUri(uri), mMinMaxCacheDirty(true)
 {
@@ -88,7 +98,11 @@ email                : sherman at mrcc.com
             // We don't know anything about a text based field other
             // than its name. All fields are assumed to be text
             int fieldPos = 0;
-            for ( QStringList::Iterator it = fieldList.begin(); it != fieldList.end(); ++it ) {
+            for ( QStringList::Iterator it = fieldList.begin(); it != fieldList.end(); ++it ) 
+            {
+              QString field = *it;
+              if(field.length() > 0)
+              {
               attributeFields.push_back(QgsField(*it, "Text"));
               fieldPositions[*it] = fieldPos++;
               // check to see if this field matches either the x or y field
@@ -110,7 +124,11 @@ email                : sherman at mrcc.com
               std::cerr << "Adding field: " << *it << std::endl; 
 #endif
 
+            }
             }           
+#ifdef QGISDEBUG 
+            std::cerr << "Field count for the delimited text file is " << attributeFields.size() << std::endl; 
+#endif 
           }else
           {
             // examine the x,y and update extents
@@ -381,6 +399,7 @@ QgsFeature *QgsDelimitedTextProvider::getNextFeature(bool fetchAttributes)
             // selection rectangle or the EOF is reached
             while(!stream.atEnd() && !processPoint)
             {
+		++mFid;
               line = stream.readLine();
 
               // create the geometry from the x, y fields
@@ -444,7 +463,99 @@ QgsFeature *QgsDelimitedTextProvider::getNextFeature(bool fetchAttributes)
 
 QgsFeature * QgsDelimitedTextProvider::getNextFeature(std::list<int>& attlist)
 {
-    return 0;//soon
+     // We must manually check each point to see if it is within the
+  // selection rectangle
+  QgsFeature *f = 0;
+  bool processPoint;
+  if(mValid){
+    // read the line
+    QTextStream stream( mFile );
+    QString line;
+    if ( !stream.atEnd() ) {
+      line = stream.readLine(); // line of text excluding '\n'
+      // create the geometry from the x, y fields
+      QStringList parts = QStringList::split(QRegExp(mDelimiter), line, true);
+      // Get the x and y values, first checking to make sure they
+      // aren't null.
+      QString sX = parts[fieldPositions[mXField]];
+      QString sY = parts[fieldPositions[mYField]];
+      //std::cout << "x ,y " << sX << ", " << sY << std::endl; 
+      bool xOk = true;
+      bool yOk = true;
+      double x = sX.toDouble(&xOk);
+      double y = sY.toDouble(&yOk);
+      if(xOk && yOk)
+      {
+        if(mSelectionRectangle == 0)
+        {
+          // no selection in place
+          processPoint = true;
+        }else
+        {
+          // check to see if point is in bounds
+          processPoint = boundsCheck(x, y);
+          if(!processPoint)
+          {
+            // we need to continue to read until we get a hit in the
+            // selection rectangle or the EOF is reached
+            while(!stream.atEnd() && !processPoint)
+            {
+		++mFid;
+              line = stream.readLine();
+
+              // create the geometry from the x, y fields
+              parts = QStringList::split(QRegExp(mDelimiter), line, true);
+              // Get the x and y values, first checking to make sure they
+              // aren't null.
+              sX = parts[fieldPositions[mXField]];
+              sY = parts[fieldPositions[mYField]];
+              //std::cout << "x ,y " << sX << ", " << sY << std::endl; 
+              xOk = true;
+              yOk = true;
+              x = sX.toDouble(&xOk);
+              y = sY.toDouble(&yOk);
+              if(xOk && yOk)
+              {
+                processPoint = boundsCheck(x, y);
+              }
+
+            }
+          }
+        }
+        if(processPoint)
+        {
+          //std::cout << "Processing " << x << ", " << y << std::endl; 
+          // create WKBPoint
+          wkbPoint wkbPt;
+          unsigned char * geometry = new unsigned char[sizeof(wkbPt)];
+          geometry[0] = endian();
+          int type = 1;
+          void *ptr = geometry+1;
+          memcpy((void*)(geometry +1), &type, 4);
+          memcpy((void*)(geometry +5), &x, sizeof(x));
+          memcpy((void*)(geometry +13), &y, sizeof(y));
+          /*
+             geometry->byteOrder = endian();
+             geometry->wkbType = 1;
+             geometry->x = x;
+             geometry->y = y;
+             */
+          f = new QgsFeature();
+          f->setGeometry(geometry, sizeof(wkbPt));
+          //std::cerr << "Setting feature id to " << mFid << std::endl; 
+          f->setFeatureId(mFid++);
+          
+          // add the attributes to the attribute map
+	      for(std::list<int>::iterator iter=attlist.begin();iter!=attlist.end();++iter)
+	      {
+		  f->addAttribute(attributeFields.at(*iter).name(), parts[*iter]);
+	      }
+        }
+      }
+    }
+
+  }
+  return f;
 }
 
 /**
@@ -501,6 +612,12 @@ std::vector<QgsFeature>& QgsDelimitedTextProvider::identify(QgsRect * rect)
     << rect->stringRep() << std::endl; 
   // select the features
   select(rect);
+#ifdef WIN32
+  //TODO fix this later for win32
+  std::vector<QgsFeature> feat;
+  return feat;
+#endif
+
 }
 
 /*
@@ -651,6 +768,7 @@ void QgsDelimitedTextProvider::fillMinMaxCash()
 bool QgsDelimitedTextProvider::isValid(){
   return mValid;
 }
+
 /** 
  * Check to see if the point is within the selection rectangle
  */
@@ -660,35 +778,236 @@ bool QgsDelimitedTextProvider::boundsCheck(double x, double y)
         (x > mSelectionRectangle->xMin())) &&
       ((y < mSelectionRectangle->yMax()) &&
        (y > mSelectionRectangle->yMin())));
-  QString hit = inBounds?"true":"false";
-  //  std::cerr << "Checking if " << x << ", " << y << " is in " << 
-  //mSelectionRectangle->stringRep() << ": " << hit << std::endl; 
+ // QString hit = inBounds?"true":"false";
+
+ // std::cerr << "Checking if " << x << ", " << y << " is in " << 
+ //mSelectionRectangle->stringRep().ascii() << ": " << hit.ascii() << std::endl; 
   return inBounds;
 }
+bool QgsDelimitedTextProvider::supportsSaveAsShapefile()
+{
+  return true;
+}
+
+bool QgsDelimitedTextProvider::saveAsShapefile()
+{
+  // save the layer as a shapefile
+  QString driverName = "ESRI Shapefile";
+  OGRSFDriver *poDriver;
+  OGRRegisterAll();
+  poDriver = OGRSFDriverRegistrar::GetRegistrar()->GetDriverByName((const char *)driverName );
+  bool returnValue = true;
+  if( poDriver != NULL )
+  {
+    // get a name for the shapefile
+    // Get a file to process, starting at the current directory
+    // Set inital dir to last used in delimited text plugin
+    QSettings settings;
+
+    QString shapefileName = QFileDialog::getSaveFileName(
+        settings.readEntry("/Qgis/delimited_text_plugin/text_path","./"),
+        "Shapefiles (*.shp)",
+        0,
+        "open file dialog",
+        "Save delimited text layer as shapefile" );
+
+    if(!shapefileName.isNull())
+    {
+      // add the extension if not present
+      if(shapefileName.find(".shp") == -1)
+      {
+        shapefileName += ".shp";
+      }
+      OGRDataSource *poDS;
+      // create the data source
+      poDS = poDriver->CreateDataSource( (const char *)shapefileName, NULL );
+      if( poDS != NULL )
+      {
+        std::cerr << "created datasource" << std::endl; 
+        // datasource created, now create the output layer
+        OGRLayer *poLayer;
+        poLayer = poDS->CreateLayer((const char *)shapefileName.left(shapefileName.find(".shp")), NULL, static_cast<OGRwkbGeometryType>(1), NULL );
+        if( poLayer != NULL )
+        {
+          std::cerr << "created layer" << std::endl; 
+          // calculate the field lengths
+          int *lengths = getFieldLengths();
+          // create the fields
+          std::cerr << "creating " << attributeFields.size() << " fields" << std::endl; 
+          for(int i = 0; i < attributeFields.size(); i++)
+          {
+            // check the field length - if > 10 we need to truncate it
+            QgsField attrField = attributeFields[i];
+            if(attrField.name().length() > 10)
+            {
+              attrField = attrField.name().left(10);
+            }
+            // all fields are created as string (for now)
+            OGRFieldDefn fld(attrField.name(), OFTString);
+            // set the length for the field -- but we don't know what it is...
+            fld.SetWidth(lengths[i]);
+            // create the field
+            std::cerr << "creating field " << attrField.name() << " width length " << lengths[i] << std::endl; 
+            if(poLayer->CreateField(&fld) != OGRERR_NONE)
+            {
+              QMessageBox::warning(0, "Error", "Error creating field " + attrField.name());
+            }
+          }
+          // read the delimited text file and create the features
+          std::cerr << "Done creating fields" << std::endl; 
+          // read the line
+          reset();
+          QTextStream stream( mFile );
+          QString line;
+          while ( !stream.atEnd() ) {
+            line = stream.readLine(); // line of text excluding '\n'
+            std::cerr << line << std::endl; 
+            // split the line
+            QStringList parts = QStringList::split(QRegExp(mDelimiter), line, true);
+            std::cerr << "Split line into " << parts.size() << std::endl; 
+
+            // create the feature
+            OGRFeature *poFeature;
+
+            poFeature = new OGRFeature( poLayer->GetLayerDefn() );
+
+            // iterate over the parts and set the fields
+            std::cerr << "Setting the field values" << std::endl; 
+            // set limit - we will ignore extra fields on the line
+            int limit = attributeFields.size();
+
+            if(parts.size() < limit){
+            
+              // this is bad - not enough values where supplied on the line
+              // TODO We should inform the user about this...
+            }
+            else
+            {
+
+            for ( int i = 0; i < limit; i++ ) 
+            {
+              if(parts[i] != QString::null)
+              {
+                std::cerr << "Setting " << i << " "  << attributeFields[i].name() << " to " << parts[i] << std::endl; 
+                poFeature->SetField(attributeFields[i].name(), parts[i]);
+
+              }
+              else
+              {
+                poFeature->SetField(attributeFields[i].name(), "");
+              }
+            }
+            std::cerr << "Field values set" << std::endl; 
+            // create the point
+            OGRPoint *poPoint = new OGRPoint();
+            QString sX = parts[fieldPositions[mXField]];
+            QString sY = parts[fieldPositions[mYField]];
+            poPoint->setX(sX.toDouble());
+            poPoint->setY(sY.toDouble());
+            std::cerr << "Setting geometry" << std::endl; 
+
+            poFeature->SetGeometryDirectly(poPoint);
+            if(poLayer->CreateFeature(poFeature) != OGRERR_NONE)
+            {
+              std::cerr << "Failed to create feature in shapefile" << std::endl; 
+            }
+            else
+            {
+              std::cerr << "Added feature" << std::endl; 
+            }
+
+            delete poFeature;
+          }
+          }
+          delete poDS;
+        }
+        else
+        {
+          QMessageBox::warning(0,"Error", "Layer creation failed");
+        }
+
+      }
+      else
+      {
+        QMessageBox::warning(0, "Error creating shapefile", 
+            "The shapefile could not be created (" + shapefileName + ")");
+      }
+
+    }
+    //std::cerr << "Saving to " << shapefileName << std::endl; 
+  }
+  else
+  {
+    QMessageBox::warning(0, "Driver not found", driverName +  " driver is not available");
+    returnValue = false;
+  }
+  return returnValue;
+}
+
+
+int* QgsDelimitedTextProvider::getFieldLengths()
+{
+  // this function parses the entire data file and calculates the
+  // max for each
+
+  // Only do this if we haven't done it already (ie. the vector is
+  // empty)
+  int *lengths = new int[attributeFields.size()];
+  // init the lengths to zero
+  for(int il=0; il < attributeFields.size(); il++)
+  {
+    lengths[il] = 0;
+  }
+  if(mValid){
+    reset();
+    // read the line
+    QTextStream stream( mFile );
+    QString line;
+    while ( !stream.atEnd() ) {
+      line = stream.readLine(); // line of text excluding '\n'
+      // split the line
+      QStringList parts = QStringList::split(QRegExp(mDelimiter), line, true);
+      // iterate over the parts and update the max value
+      for ( int i = 0; i < parts.size(); i++ ) 
+      {
+       if(parts[i] != QString::null)
+       { 
+       // std::cerr << "comparing length for " << parts[i] << " against max len of " << lengths[i] << std::endl; 
+        if(parts[i].length() > lengths[i])
+        {
+          lengths[i] = parts[i].length();
+        }
+       }
+
+      }
+    }
+  }
+  return lengths;
+}
 /**
  * Class factory to return a pointer to a newly created 
  * QgsDelimitedTextProvider object
  */
-extern "C" QgsDelimitedTextProvider * classFactory(const char *uri)
+QGISEXTERN QgsDelimitedTextProvider * classFactory(const char *uri)
 {
   return new QgsDelimitedTextProvider(uri);
 }
 /** Required key function (used to map the plugin to a data store type)
 */
-extern "C" QString providerKey(){
+QGISEXTERN QString providerKey(){
   return QString("delimitedtext");
 }
 /**
  * Required description function 
  */
-extern "C" QString description(){
+QGISEXTERN QString description(){
   return QString("Delimited text data provider");
 } 
 /**
  * Required isProvider function. Used to determine if this shared library
  * is a data provider plugin
  */
-extern "C" bool isProvider(){
+QGISEXTERN bool isProvider(){
   return true;
 }
 
