@@ -1,6 +1,6 @@
 /***************************************************************************
-		 gsrasterlayer.h  -  description
-			 -------------------
+                        qgsrasterlayer.h  -  description
+                              -------------------
 	begin                : Fri Jun 28 2002
 	copyright            : (C) 2004 by T.Sutton, Gary E.Sherman, Steve Halasz
 	email                : tim@linfiniti.com
@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* $Id */
+/* $Id: qgsrasterlayer.h,v 1.51 2004/11/15 21:52:57 mhugent Exp $ */
 
 /** \file qgsrasterlayer.h
  *  \brief This class provides qgis with the ability to render raster datasets
@@ -168,14 +168,18 @@ The [type] part of the variable should be the type class of the variable written
  
 #include <qvaluevector.h>
 #include <qvaluelist.h> 
+#include <qslider.h>
 #include "qgspoint.h"
 #include "qgsmaplayer.h"
+#include "qgscolortable.h"
 #include "qgsrasterlayer.h"
 
+#include <gdal_priv.h>
 //
 // Forward declarations
 //
 class QgsRect;
+class QgsRasterLayerProperties;
 class GDALDataset;
 class GDALRasterBand;
 class QImage;
@@ -215,6 +219,10 @@ struct RasterBandStats
     /** \brief The number of cells in the band. Equivalent to height x width. 
      * TODO: check if NO_DATA are excluded!*/
     int elementCountInt;    
+    /** \brief A histogram storing the distribution of values within the raster. */
+    int histogram[256];
+    /** Color table */
+    QgsColorTable colorTable;
 };
 
 /** \brief  A vector containing one RasterBandStats struct per raster band in this raster layer.
@@ -311,6 +319,21 @@ class QgsRasterLayer : public QgsMapLayer
 {
     Q_OBJECT
 public:
+    //
+    // Static methods:
+    //
+        
+    static void buildSupportedRasterFileFilter(QString & fileFilters);
+    static bool isSupportedRasterDriver(QString const &driverName);
+    /** This helper checks to see whether the filename appears to be a valid raster file name */
+    static bool isValidRasterFileName(QString theFileNameQString);
+    /** Overloaded version of the above function provided for convenience that takes a qstring pointer */
+    static bool isValidRasterFileName(QString * theFileNameQString);
+
+    //
+    // Non Static methods:
+    //
+        
     /** \brief This is the constructor for the RasterLayer class.
      *
      * The main tasks carried out by the constructor are:
@@ -326,15 +349,20 @@ public:
      * -
      * */
     QgsRasterLayer(QString path = 0, QString baseName = 0);
+
     /** \brief The destuctor.  */
     ~QgsRasterLayer();
-    /** \brief This method is called when the properties for this layer needs to be modified. 
-     * invokes an instance of the QgsRasterLayerProperties dialog box.*/
-     void showLayerProperties();
+
+
     /** \brief Draws a thumbnail of the rasterlayer into the supplied pixmap pointer */
      void drawThumbnail(QPixmap * theQPixmap);
+
+    /** \brief Get an 8x8 pixmap of the colour palette. If the layer has no palette a white pixmap will be returned. */
+     QPixmap getPaletteAsPixmap();
+     
     /** \brief This is called when the view on the rasterlayer needs to be refreshed (redrawn).  */
-    void draw(QPainter * theQPainter, QgsRect * theViewExtent, QgsCoordinateTransform * theQgsCoordinateTransform, QPaintDevice* src, QPaintDevice* dst);
+    void draw(QPainter * theQPainter, QgsRect * theViewExtent, QgsCoordinateTransform * theQgsCoordinateTransform, QPaintDevice* dst);
+
     /** \brief This is an overloaded version of the above function that is called by both draw above and drawThumbnail */
     void draw (QPainter * theQPainter, RasterViewPort * myRasterViewPort);
     
@@ -343,15 +371,19 @@ public:
     //
     /** \brief Accessor that returns the width of the (unclipped) raster  */
     const int getRasterXDim() {return rasterXDimInt;};
+
     /** \brief Accessor that returns the height of the (unclipped) raster  */
     const int getRasterYDim() {return rasterYDimInt;};
+
     //
     // Accessor and mutator for no data double
     //
     /** \brief  Accessor that returns the NO_DATA entry for this raster. */
-    const double getNoDataValue() {return noDataValueDouble;};
+    const double getNoDataValue() {return noDataValueDouble;}
+
     /** \brief  Mutator that allows the  NO_DATA entry for this raster to be overridden. */
     void setNoDataValue(double theNoDataDouble) { noDataValueDouble=theNoDataDouble; return;};
+
     //
     // Accessor and mutator for invertHistogramFlag
     //
@@ -403,7 +435,7 @@ public:
     /** \brief accessor for transparency level.  */
     unsigned int getTransparency();
     /** \brief Mutator for transparency level. Should be between 0 and 255 */
-    void setTransparency(unsigned int); //
+    void setTransparency(int); //
     /** \brief Call any inline image manipulation filters */
     void filterLayer(QImage * theQImage);
     /** \brief Accessor for red band name (allows alternate mappings e.g. map blue as red colour). */
@@ -660,9 +692,11 @@ public:
     {
         SINGLE_BAND_GRAY, // a "Gray" or "Undefined" layer drawn as a range of gray colors
         SINGLE_BAND_PSEUDO_COLOR,// a "Gray" or "Undefined" layer drawn using a pseudocolor algorithm
+        PALETTED_COLOR, //a "Palette" image drawn using color table
         PALETTED_SINGLE_BAND_GRAY,// a "Palette" layer drawn in gray scale (using only one of the color components)
         PALETTED_SINGLE_BAND_PSEUDO_COLOR, // a "Palette" layer having only one of its color components rendered as psuedo color
-        PALETTED_MULTI_BAND_COLOR, //a "Palette" image where the bands contains 24bit color info and 8 bits is pulled out per color
+        PALETTED_MULTI_BAND_COLOR, // a "Palette" image is decomposed to 3 channels (RGB) and drawn 
+	                           // as multiband 
         MULTI_BAND_SINGLE_BAND_GRAY, // a layer containing 2 or more bands, but using only one band to produce a grayscale image
         MULTI_BAND_SINGLE_BAND_PSEUDO_COLOR, //a layer containing 2 or more bands, but using only one band to produce a pseudocolor image
         MULTI_BAND_COLOR //a layer containing 2 or more bands, mapped to the three RGBcolors. In the case of a multiband with only two bands, one band will have to be mapped to more than one color
@@ -686,6 +720,10 @@ public:
      * NOTE: May be deprecated in the future! Use alternate implementation above rather.
      * */
     void setDrawingStyle(QString theDrawingStyleQString);
+
+
+
+
     /** \brief This enumerator describes the type of raster layer.  */
     enum RASTER_LAYER_TYPE
     {
@@ -708,8 +746,13 @@ public:
     /** \brief Similar to above but returns a pointer. Implemented for qgsmaplayer interface. 
      * Always overlays legend name!*/
     QPixmap * legendPixmap(); 
-    /** \brief Initialiser for the right click popup menu.  */
-    void initContextMenu(QgisApp *);
+
+    /** tailor the right-click context menu with raster layer only stuff 
+
+      @note called by QgsMapLayer::initContextMenu();
+     */
+    void initContextMenu_(QgisApp *);
+
     /** \brief Accessor for the superclass's popmenu var - implements the pure virtual funtion. */
     QPopupMenu *contextMenu();
     /** \brief Emit a signal asking for a repaint. (inherited from maplayer) */
@@ -724,14 +767,24 @@ public:
     /** \brief Helper method to retrieve the nth pyramid layer struct from the PyramidList. 
      * If the nth layer does not exist, NULL will be returned. */
 //   RasterPyramid getRasterPyramid(int thePyramidNo);
+
+    /**Currently returns always false*/
+    bool isEditable() const;
     
     
 public slots:    
+
+    /** sets whether this is in overview or not */
+    void inOverview( bool );
+
+    /** \brief Slot called when the popup menu transparency slider has been moved.*/
+    void popupTransparencySliderMoved(int);
+     
     /** \brief Create  gdal pyramid overviews  for this layer.
     * This will speed up performance at the expense of hard drive space.
     * Also, write access to the file is required. If no paramter is passed in
-    * it will default to the class member pyramid list. */
-    void buildPyramids(RasterPyramidList);
+    * it will default to nearest neighbor resampling. */
+    void buildPyramids(RasterPyramidList,QString theResamplingMethod="NEAREST");
     /** \brief Used at the moment by the above function but hopefully will later
     be useable by any operation that needs to notify the user of its progress. */
 /*
@@ -739,6 +792,35 @@ public slots:
                           const char *theMessageCharArray,
                           void *theData);    
 */
+
+    /** \brief This method is called when the properties for this layer needs to be modified. 
+     * invokes an instance of the QgsRasterLayerProperties dialog box.*/
+    /* virtual */ void showLayerProperties();
+
+
+ protected:
+
+    /** reads vector layer specific state from project file DOM node.
+
+        @note
+
+        Called by QgsMapLayer::readXML().
+
+    */
+    /* virtual */ bool readXML_( QDomNode & layer_node );
+
+
+
+  /** write vector layer specific state to project file DOM node.
+
+      @note
+
+      Called by QgsMapLayer::writeXML().
+
+  */
+  /* virtual */ bool writeXML_( QDomNode & layer_node, QDomDocument & doc );
+
+
 private:
 
     //
@@ -759,9 +841,14 @@ private:
 
 
     //
-    // Pseudocolor layers
+    // Paletted Layers
     //
     
+    /** \brief Drawing routine for paletted image, rendered as a single band image in color.  */
+    void drawPalettedSingleBandColor(QPainter * theQPainter,
+                                RasterViewPort * theRasterViewPort,
+                                int theBandNoInt);
+    
     /** \brief Drawing routine for paletted image, rendered as a single band image in grayscale.  */
     void drawPalettedSingleBandGray(QPainter * theQPainter,
                                 RasterViewPort * theRasterViewPort,
@@ -796,6 +883,36 @@ private:
     /** \brief Drawing routine for multiband image  */
     void drawMultiBandColor(QPainter * theQPainter, RasterViewPort * theRasterViewPort);
 
+    /** \brief Read color table from GDAL raster band */
+    void readColorTable ( GDALRasterBand *gdalBand, QgsColorTable *theColorTable );
+
+    /** \brief Allocate memory and load data to that allocated memory, data type is the same
+     *         as raster band. The memory must be released later!
+     *  \return pointer to the memory
+     */
+    void *readData ( GDALRasterBand *gdalBand, RasterViewPort *viewPort );
+
+    /** \brief Read a raster value on given position from memory block created by readData() 
+     *  \param index index in memory block
+     */
+    inline double readValue ( void *data, GDALDataType type, int index );
+
+    /** \brief Color table 
+     *  \param band number
+     *  \return pointer to color table
+     */
+    QgsColorTable *colorTable ( int theBandNoInt );
+
+    /**
+       Load the given raster file
+
+       @returns true if successfully read file
+
+       @note
+       
+       Called from ctor if a raster image given there
+     */
+    bool readFile( QString const & fileName );
 
     //
     // Private member vars
@@ -854,11 +971,19 @@ private:
     /** \brief This list holds a series of RasterPyramid structs
      * which store infomation for each potential pyramid level for this raster.*/
     RasterPyramidList mPyramidList;
+    //Transparency slider for popup menu
+    QSlider * mTransparencySlider; 
     //we need to do the tr() stuff outside of the main drawing loops becauses tr() is a 
     //time consuming operation nd we dont want to do it in the loop!
     QString redTranslatedQString;
     QString greenTranslatedQString;
     QString blueTranslatedQString;
+
+    /* raster properties dialog 
+
+       @todo XXX should consider generalizing this
+    */
+    QgsRasterLayerProperties * mLayerProperties;
     
 };
 
